@@ -7,13 +7,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include "main.h"
-#include "audio.h"
-#include "events.h"
-#include "callbacks.h"
-#include "effects.h"
-#include "support.h"
-
 #ifdef HAVE_SYSTEM_WEED
 #include <weed/weed.h>
 #include <weed/weed-host.h>
@@ -26,6 +19,13 @@
 #include "../libweed/weed-palettes.h"
 #endif
 
+#include "main.h"
+#include "audio.h"
+#include "events.h"
+#include "callbacks.h"
+#include "effects.h"
+#include "support.h"
+
 
 // keep first 16 audio_in filesysten handles open - multitrack only
 #define NSTOREDFDS 16
@@ -2511,7 +2511,7 @@ gboolean get_audio_from_plugin(float *fbuffer, int nchans, int arate, int nsamps
     weed_set_voidptr_value(channel,"audio_data",fbuffer);
     
     weed_set_double_value(inst,"fps",cfile->pb_fps);
-    
+
     if (mainw->agen_needs_reinit) {
       // allow main thread to complete the reinit so we do not delay; just return silence
       memset(fbuffer,0,nsamps*nchans*sizeof(float));
@@ -2522,6 +2522,24 @@ gboolean get_audio_from_plugin(float *fbuffer, int nchans, int arate, int nsamps
     weed_set_int64_value(channel,"timecode",tc);
   }
 
+
+  if (mainw->pconx!=NULL&&!(mainw->preview||mainw->is_rendering)) {
+    // chain any data pipelines
+    if (!pthread_mutex_trylock(&mainw->data_mutex)) {
+      mainw->agen_needs_reinit=pconx_chain_data(mainw->agen_key-1,rte_key_getmode(mainw->agen_key));
+      pthread_mutex_unlock(&mainw->data_mutex);
+      
+      if (mainw->agen_needs_reinit) {
+	// allow main thread to complete the reinit so we do not delay; just return silence
+	memset(fbuffer,0,nsamps*nchans*sizeof(float));
+	pthread_mutex_unlock(&mainw->interp_mutex);
+	return FALSE;
+      }
+    }
+  }
+
+
+
   weed_leaf_get(filter,"process_func",0,(void *)&process_func_ptr_ptr);
   process_func=process_func_ptr_ptr[0];
 
