@@ -1,6 +1,6 @@
 // callbacks.h
 // LiVES
-// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2012
+// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2013
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -12,11 +12,6 @@ on_LiVES_delete_event                  (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
-gboolean
-return_true                  (GtkWidget       *widget,
-			      GdkEvent        *event,
-			      gpointer         user_data);
-
 void
 on_open_activate                      (GtkMenuItem     *menuitem,
 				       gpointer         user_data);
@@ -196,6 +191,13 @@ void
 on_ok_button1_clicked                  (GtkButton       *button,
                                         gpointer         user_data);
 
+
+void on_ok_file_open_clicked(GtkFileChooser *chooser, GSList *fnames);
+
+void on_ok_filesel_open_clicked (GtkFileChooser *chooser, gpointer user_data);
+
+
+
 void
 open_sel_range_activate                 (void);
 
@@ -226,7 +228,7 @@ on_open_sel_ok_button_clicked                  (GtkButton       *button,
 void on_save_textview_clicked (GtkButton *button, gpointer user_data);
 
 void
-on_cancel_button1_clicked              (GtkButton       *button,
+on_cancel_button1_clicked              (GtkWidget       *widget,
                                         gpointer         user_data);
 
 gboolean on_cancel_button1_clicked_del(GtkWidget *widget, GdkEvent *event, gpointer user_data);
@@ -278,10 +280,6 @@ on_mute_activate                (GtkMenuItem     *menuitem,
 				 gpointer         user_data);
 
 
-void
-on_general_button_clicked            (GtkButton       *button,
-				      gpointer         user_data);
-
 void
 on_details_button_clicked            (GtkButton       *button,
 				      gpointer         user_data);
@@ -307,7 +305,7 @@ void
 on_spinbutton_end_value_changed          (GtkSpinButton   *spinbutton,
 					  gpointer         user_data);
 
-void on_open_new_audio_clicked (GtkButton *, gpointer opt_filename);
+void on_open_new_audio_clicked (GtkFileChooser *chooser, gpointer opt_filename);
 
 void on_load_audio_activate (GtkMenuItem *, gpointer user_data);
 
@@ -322,9 +320,7 @@ void
 on_xmms_play_audio_activate                  (GtkMenuItem     *menuitem,
 					      gpointer         user_data);
 
-void 
-on_xmms_ok_clicked                (GtkButton     *menuitem,
-					 gpointer         user_data);
+void on_xmms_ok_clicked (GtkFileChooser *chooser, gpointer user_data);
 
 void 
 on_xmms_stop_audio_activate                (GtkMenuItem     *menuitem,
@@ -457,9 +453,8 @@ gboolean
 frame_context           (GtkWidget       *widget,
 			  GdkEventButton  *event,
 			  gpointer         which);
-void
-on_fs_preview_clicked                  (GtkButton       *button,
-                                        gpointer         user_data);
+
+void on_fs_preview_clicked (GtkWidget *widget, gpointer user_data);
 
 
 void
@@ -470,14 +465,6 @@ void
 on_backup_activate                      (GtkMenuItem     *menuitem,
 					 gpointer         user_data);
 
-void
-on_backup_ok_clicked                  (GtkButton       *button,
-				       gpointer         user_data);
-
-void
-on_restore_ok_clicked                  (GtkButton       *button,
-				       gpointer         user_data);
-
 void
 on_xmms_ran_ok_clicked                  (GtkButton       *button,
 				       gpointer         user_data);
@@ -562,7 +549,7 @@ on_recaudsel_activate (GtkMenuItem     *menuitem,
 void
 on_recaudclip_ok_clicked                      (GtkButton *button,
 					       gpointer user_data);
-#ifdef HAVE_GTK_NICE_VERSION
+#if GTK_CHECK_VERSION(2,14,0)
 void
 on_volume_slider_value_changed           (GtkScaleButton   *sbutton,
 					  gpointer user_data);
@@ -576,9 +563,7 @@ void
 on_fade_audio_activate (GtkMenuItem     *menuitem,
 			  gpointer         user_data);
 
-void
-on_ok_append_audio_clicked                      (GtkButton *button,
-						 GtkEntry *entry);
+void on_ok_append_audio_clicked (GtkFileChooser *chooser, gpointer user_data);
 
 void
 on_resample_video_activate (GtkMenuItem     *menuitem,
