@@ -57,6 +57,9 @@ weed_plant_t *weed_instance_get_filter(weed_plant_t *inst, boolean get_compound_
 int num_compound_fx(weed_plant_t *plant); // return number of filters in a compund fx (1 if it is not compound) - works for filter or inst
 void load_compound_fx(void);
 
+gboolean has_non_alpha_palette(weed_plant_t *ctmpl);
+gboolean has_alpha_palette(weed_plant_t *ctmpl);
+
 gboolean is_audio_channel_in(weed_plant_t *inst, int chnum);
 gboolean has_video_chans_in(weed_plant_t *filter, gboolean count_opt);
 gboolean has_audio_chans_in(weed_plant_t *filter, gboolean count_opt);
@@ -73,6 +76,8 @@ lives_fx_cat_t weed_filter_categorise (weed_plant_t *pl, int in_channels, int ou
 lives_fx_cat_t weed_filter_subcategorise (weed_plant_t *pl, lives_fx_cat_t category, gboolean count_opt);
 #endif
 
+gchar* weed_seed_type_to_text(int seed_type);
+
 gboolean has_usable_palette(weed_plant_t *chantmpl);
 int check_weed_palette_list (int *palette_list, int num_palettes, int palette);
 
@@ -93,9 +98,12 @@ void weed_reinit_all(void);
 
 int weed_flagset_array_count(weed_plant_t **array, gboolean set_readonly);
 
+int num_alpha_channels(weed_plant_t *filter, boolean out);
+
 gint num_in_params(weed_plant_t *, boolean skip_hidden, boolean skip_internal);
 int num_out_params(weed_plant_t *);
 weed_plant_t *weed_inst_in_param (weed_plant_t *inst, int param_num, boolean skip_hidden, boolean skip_internal);
+weed_plant_t *weed_inst_out_param (weed_plant_t *inst, int param_num);
 weed_plant_t *weed_filter_in_paramtmpl (weed_plant_t *filter, int param_num, boolean skip_internal);
 gboolean is_hidden_param(weed_plant_t *, int i);
 int get_nth_simple_param(weed_plant_t *, int pnum);
