@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@xs4all.nl,salsaman@gmail.com) 2003 - 2012
+// (c) G. Finch (salsaman@xs4all.nl,salsaman@gmail.com) 2003 - 2013
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -771,6 +771,7 @@ void add_to_playframe (void);
 GtkWidget* create_cdtrack_dialog (gint type, gpointer user_data);
 GtkTextView *create_output_textview(void);
 gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, GtkFileChooserAction act, const char *title, GtkWidget *extra);
+void choose_file_with_preview (gchar *dir, const gchar *title, gint preview_type);
 void add_suffix_check(GtkBox *box, const gchar *ext);
 
 
@@ -891,7 +892,6 @@ void do_threaded_dialog(gchar *translated_text, gboolean has_cancel);
 void end_threaded_dialog(void);
 void threaded_dialog_spin (void);
 void response_ok (GtkButton *button, gpointer user_data);
-void response_cancel (GtkButton *button, gpointer user_data);
 void pump_io_chan(GIOChannel *iochan);
 
 void do_splash_progress(void);
@@ -1193,7 +1193,7 @@ void popup_lmap_errors(GtkMenuItem *, gpointer);
 
 
 // paramspecial.c
-gboolean mt_framedraw(lives_mt *, GdkPixbuf *);
+boolean mt_framedraw(lives_mt *, GdkPixbuf *);
 
 // paramwindow.c
 void add_fill_to_box (GtkBox *);
@@ -1206,6 +1206,7 @@ void * lives_malloc(size_t size);
 void *lives_memcpy(void *dest, const void *src, size_t n);
 void *lives_memset(void *s, int c, size_t n);
 void lives_free(void *ptr); ///< calls mainw->free_fn
+void *lives_calloc(size_t nmemb, size_t size);
 
 /// values of mainw->free_fn
 void lives_free_normal(void *ptr);
