@@ -1377,7 +1377,8 @@ static omclearn_w *create_omclearn_dialog(void) {
   gtk_widget_show (ok_button);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
   
-  GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
+  lives_widget_set_can_focus_and_default (ok_button);
+
   gtk_widget_grab_default (ok_button);
   
   g_signal_connect (GTK_OBJECT (ok_button), "clicked",
@@ -1385,8 +1386,10 @@ static omclearn_w *create_omclearn_dialog(void) {
 		    NULL);
   
   if (prefs->gui_monitor!=0) {
-    gint xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width-omclw->dialog->allocation.width)/2;
-    gint ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height-omclw->dialog->allocation.height)/2;
+    gint xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width
+						    -lives_widget_get_allocation_width(omclw->dialog))/2;
+    gint ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height
+						    -lives_widget_get_allocation_height(omclw->dialog))/2;
     gtk_window_set_screen(GTK_WINDOW(omclw->dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
     gtk_window_move(GTK_WINDOW(omclw->dialog),xcen,ycen);
   }
