@@ -1,6 +1,6 @@
 // paramspecial.c
 // LiVES
-// (c) G. Finch 2004 - 2012 <salsaman@xs4all.nl,salsaman@gmail.com>
+// (c) G. Finch 2004 - 2013 <salsaman@xs4all.nl,salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -190,18 +190,19 @@ void fd_connect_spinbutton(lives_rfx_t *rfx) {
 
 
 static void passwd_toggle_vis(GtkToggleButton *b, gpointer entry) {
-  gtk_entry_set_visibility(GTK_ENTRY(entry),gtk_toggle_button_get_active(b));
+  gtk_entry_set_visibility(GTK_ENTRY(entry),lives_toggle_button_get_active(b));
 }
 
 
-void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_t *rfx) {
+void check_for_special (lives_param_t *param, int num, GtkBox *pbox, lives_rfx_t *rfx) {
   GtkWidget *checkbutton;
   GtkWidget *hbox;
-  GtkWidget *eventbox;
   GtkWidget *box;
   GtkWidget *buttond;
-  GtkWidget *label;
   GList *slist;
+
+  gchar *tmp,*tmp2;
+
   // check if this parameter is part of a special window
   // as we are drawing the paramwindow
 
@@ -252,38 +253,20 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
 						 NULL);
       
       box = gtk_hbox_new (FALSE, 10);
-      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (pbox)), box, TRUE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (pbox)), box, FALSE, FALSE, 20);
       
       
+      add_fill_to_box(GTK_BOX(box));
       
-      
-      checkbutton = gtk_check_button_new ();
-      gtk_widget_set_tooltip_text( checkbutton, (_("Maintain aspect ratio of original frame")));
-      eventbox=gtk_event_box_new();
-      lives_tooltips_copy(eventbox,checkbutton);
-      label=gtk_label_new_with_mnemonic (_("Maintain _Aspect Ratio"));
-      
-      
-      gtk_container_add(GTK_CONTAINER(eventbox),label);
-      g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-			G_CALLBACK (label_act_toggle),
-			checkbutton);
-      if (palette->style&STYLE_1) {
-	gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-	gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-	gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-      }
-      
-      gtk_label_set_mnemonic_widget (GTK_LABEL (label),checkbutton);
-      
-      hbox = gtk_hbox_new (FALSE, 10);
-      gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
-      add_fill_to_box(GTK_BOX(hbox));
-      gtk_box_pack_start (GTK_BOX (hbox), checkbutton, FALSE, FALSE, 10);
-      gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-      add_fill_to_box(GTK_BOX(hbox));
-      GTK_WIDGET_SET_FLAGS (checkbutton, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), TRUE);
+      checkbutton = lives_standard_check_button_new ((tmp=g_strdup(_("Maintain _Aspect Ratio"))),TRUE,
+						     LIVES_BOX(box),(tmp2=g_strdup(_("Maintain aspect ratio of original frame"))));
+
+      g_free(tmp); g_free(tmp2);
+
+      add_fill_to_box(GTK_BOX(box));
+
+      gtk_widget_show_all(box);
+
       aspect.checkbutton=checkbutton;
       aspect.height_widget=param->widgets[0];
     }
@@ -297,10 +280,10 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
       GList *clist;
       gint epos;
 
-      box=(GTK_WIDGET(param->widgets[0])->parent);
+      box=lives_widget_get_parent(param->widgets[0]);
 
       while (box !=NULL&&!GTK_IS_BOX(box)) {
-	box=box->parent;
+	box=lives_widget_get_parent(box);
       }
 
       if (box==NULL) return;
@@ -314,7 +297,7 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
       gtk_box_pack_start(GTK_BOX(box),buttond,FALSE,FALSE,10);
       gtk_box_reorder_child(GTK_BOX(box),buttond,epos); // insert after label, before textbox
 
-      if (!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(param->widgets[0]))) gtk_widget_set_sensitive(buttond,FALSE);
+      if (!lives_widget_is_sensitive(param->widgets[0])) gtk_widget_set_sensitive(buttond,FALSE);
 
       g_signal_connect (GTK_FILE_CHOOSER(buttond), "selection-changed",G_CALLBACK (on_fileread_clicked),(gpointer)param->widgets[0]);
 
@@ -331,36 +314,21 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
   slist=passwd_widgets;
   while (slist!=NULL) {
     if (num==GPOINTER_TO_INT(slist->data)) {
-      box=(GTK_WIDGET(param->widgets[0])->parent);
+      box=lives_widget_get_parent(param->widgets[0]);
 
       while (!GTK_IS_VBOX(box)) {
-	box=box->parent;
+	box=lives_widget_get_parent(box);
 	if (box==NULL) continue;
       }
 
       hbox = gtk_hbox_new (FALSE, 10);
       gtk_box_pack_start (GTK_BOX (GTK_WIDGET (box)), hbox, FALSE, FALSE, 10);
       
-      eventbox=gtk_event_box_new();
-      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (hbox)), eventbox, FALSE, FALSE, 10);
-      label=gtk_label_new (_("Display Password"));
+      checkbutton = lives_standard_check_button_new (_("Display Password"),FALSE,LIVES_BOX(hbox),NULL);
 
-      checkbutton = gtk_check_button_new ();
-      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (hbox)), checkbutton, FALSE, FALSE, 10);
       gtk_button_set_focus_on_click (GTK_BUTTON(checkbutton),FALSE);
 
-      gtk_container_add(GTK_CONTAINER(eventbox),label);
-      g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-			G_CALLBACK (label_act_toggle),
-			checkbutton);
-
-      if (palette->style&STYLE_1) {
-	gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-	gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-	gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-      }
-
-      if (!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(param->widgets[0]))) gtk_widget_set_sensitive(checkbutton,FALSE);
+      if (!lives_widget_is_sensitive(param->widgets[0])) gtk_widget_set_sensitive(checkbutton,FALSE);
       gtk_widget_show_all(hbox);
 
       g_signal_connect_after (GTK_OBJECT (checkbutton), "toggled",
@@ -379,8 +347,8 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
 
 
 void after_aspect_width_changed (GtkSpinButton *spinbutton, gpointer user_data) {
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (aspect.checkbutton))) {
-    gboolean keepeven=FALSE;
+  if (lives_toggle_button_get_active (LIVES_TOGGLE_BUTTON (aspect.checkbutton))) {
+    boolean keepeven=FALSE;
     gint width=gtk_spin_button_get_value_as_int (spinbutton);
     gint height=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.height_widget));
     g_signal_handler_block (aspect.height_widget,aspect.height_func);
@@ -408,8 +376,8 @@ void after_aspect_width_changed (GtkSpinButton *spinbutton, gpointer user_data)
 
 
 void after_aspect_height_changed (GtkToggleButton *spinbutton, gpointer user_data){
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (aspect.checkbutton))) {
-    gboolean keepeven=FALSE;
+  if (lives_toggle_button_get_active (LIVES_TOGGLE_BUTTON (aspect.checkbutton))) {
+    boolean keepeven=FALSE;
     gint height=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
     gint width=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.width_widget));
 
@@ -515,7 +483,7 @@ void setmergealign (void) {
 }
 
 
-gboolean mt_framedraw(lives_mt *mt, GdkPixbuf *pixbuf) {
+boolean mt_framedraw(lives_mt *mt, GdkPixbuf *pixbuf) {
   if (framedraw.added) {
     switch (framedraw.type) {
     case FD_RECT_MULTRECT:
@@ -535,7 +503,7 @@ gboolean mt_framedraw(lives_mt *mt, GdkPixbuf *pixbuf) {
 }
 
 
-gboolean is_perchannel_multi(lives_rfx_t *rfx, gint i) {
+boolean is_perchannel_multi(lives_rfx_t *rfx, int i) {
   // updated for weed spec 1.1
   if (rfx->params[i].multi==PVAL_MULTI_PER_CHANNEL) return TRUE;
   return FALSE;
