@@ -1,6 +1,6 @@
 // widget-helper.c
 // LiVES
-// (c) G. Finch 2012 <salsaman@gmail.com>
+// (c) G. Finch 2012 - 2013 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -18,6 +18,12 @@
 // basic functions
 
 
+boolean return_true (LiVESWidget *widget, LiVESEvent *event, LiVESObjectPtr user_data) {
+  // event callback that just returns TRUE
+  return TRUE;
+}
+
+
 
 LIVES_INLINE void lives_object_unref(LiVESObjectPtr object) {
 #ifdef GUI_GTK
@@ -38,6 +44,18 @@ LIVES_INLINE LiVESWidget *lives_dialog_get_content_area(LiVESDialog *dialog) {
 #endif
 }
 
+LIVES_INLINE LiVESWidget *lives_dialog_get_action_area(LiVESDialog *dialog) {
+#ifdef GUI_GTK
+
+#if GTK_CHECK_VERSION(2,14,0)
+  return gtk_dialog_get_action_area(GTK_DIALOG(dialog));
+#else
+  return GTK_DIALOG(dialog)->vbox;
+#endif
+
+#endif
+}
+
 
 
 
@@ -323,24 +341,6 @@ void lives_tooltips_set(LiVESWidget *widget, const char *tip_text) {
 }
 
 
-/*
- * Set active string to the combo box
- */
-void lives_combo_set_active_string(LiVESCombo *combo, const char *active_str) {
-
-#ifdef GUI_GTK
-  gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo))),active_str);
-#endif
-
-}
-
-LiVESWidget *lives_combo_get_entry(LiVESCombo *widget) {
-#ifdef GUI_GTK
-  return gtk_bin_get_child(GTK_BIN(widget));
-#endif
-}
-
-
 LiVESSList *lives_radio_button_get_group(LiVESRadioButton *rbutton) {
 #ifdef GUI_GTK
   return gtk_radio_button_get_group(rbutton);
@@ -348,11 +348,208 @@ LiVESSList *lives_radio_button_get_group(LiVESRadioButton *rbutton) {
 }
 
 
+LiVESWidget *lives_widget_get_parent(LiVESWidget *widget) {
+#ifdef GUI_GTK
+  return gtk_widget_get_parent(widget);
+#endif
+}
+
+
+LiVESXWindow *lives_widget_get_xwindow(LiVESWidget *widget) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,12,0)
+  return gtk_widget_get_window(widget);
+#else
+  return GDK_WINDOW(widget->window);
+#endif
+#endif
+}
+
+void lives_widget_set_can_focus(LiVESWidget *widget, boolean state) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_can_focus(widget,state);
+#else
+  if (state)
+    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
+  else
+    GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+#endif
+#endif
+}
+
+
+void lives_widget_set_can_default(LiVESWidget *widget, boolean state) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_can_default(widget,state);
+#else
+  if (state)
+    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+  else
+    GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_DEFAULT);
+#endif
+#endif
+}
+
+
+boolean lives_widget_is_sensitive(LiVESWidget *widget) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  return gtk_widget_is_sensitive(widget);
+#else
+  return GTK_WIDGET_IS_SENSITIVE (widget);
+#endif
+#endif
+}
+
+boolean lives_widget_is_visible(LiVESWidget *widget) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  return gtk_widget_get_visible(widget);
+#else
+  return GTK_WIDGET_VISIBLE (widget);
+#endif
+#endif
+}
+
+
+void lives_container_remove(LiVESContainer *container, LiVESWidget *widget) {
+#ifdef GUI_GTK
+  gtk_container_remove(container,widget);
+#endif
+}
+
+
+void lives_ruler_set_range(LiVESRuler *ruler, double lower, double upper, double position, double max_size) {
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  gtk_range_set_range(GTK_RANGE(ruler),upper,lower);
+  gtk_range_set_value(GTK_RANGE(ruler),position);
+#else
+  gtk_ruler_set_range(ruler,lower,upper,position,max_size);
+#endif
+#endif
+}
+
+
+double lives_ruler_get_value(LiVESRuler *ruler) {
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  return gtk_range_get_value(GTK_RANGE(ruler));
+#else
+  return ruler->position;
+#endif
+#endif
+}
+
+double lives_ruler_set_value(LiVESRuler *ruler, double value) {
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  gtk_range_set_value(GTK_RANGE(ruler),value);
+#else
+  ruler->position=value;
+#endif
+#endif
+  return value;
+}
+
+
+double lives_ruler_set_upper(LiVESRuler *ruler, double value) {
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  gtk_adjustment_set_upper(gtk_range_get_adjustment(GTK_RANGE(ruler)),value);
+#else
+  ruler->upper=value;
+#endif
+#endif
+  return value;
+}
+
+
+double lives_ruler_set_lower(LiVESRuler *ruler, double value) {
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  gtk_adjustment_set_lower(gtk_range_get_adjustment(GTK_RANGE(ruler)),value);
+#else
+  ruler->lower=value;
+#endif
+#endif
+  return value;
+}
+
+
+int lives_widget_get_allocation_x(LiVESWidget *widget) {
+  int x=0;
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  GtkAllocation alloc;
+  gtk_widget_get_allocation(widget,&alloc);
+  x=alloc.x;
+#else
+  x=widget->allocation.x;
+#endif
+#endif
+  return x;
+}
+
+
+int lives_widget_get_allocation_y(LiVESWidget *widget) {
+  int y=0;
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  GtkAllocation alloc;
+  gtk_widget_get_allocation(widget,&alloc);
+  y=alloc.y;
+#else
+  y=widget->allocation.y;
+#endif
+#endif
+  return y;
+}
+
+int lives_widget_get_allocation_width(LiVESWidget *widget) {
+  int width=0;
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  GtkAllocation alloc;
+  gtk_widget_get_allocation(widget,&alloc);
+  width=alloc.width;
+#else
+  width=widget->allocation.width;
+#endif
+#endif
+  return width;
+}
+
+int lives_widget_get_allocation_height(LiVESWidget *widget) {
+  int height=0;
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(2,18,0)
+  GtkAllocation alloc;
+  gtk_widget_get_allocation(widget,&alloc);
+  height=alloc.height;
+#else
+  height=widget->allocation.height;
+#endif
+#endif
+  return height;
+}
+
+
+LiVESWidget *lives_bin_get_child(LiVESBin *bin) {
+  LiVESWidget *child=NULL;
+#ifdef GUI_GTK
+  child=gtk_bin_get_child(bin);
+#endif
+  return child;
+}
+
+
 
 // compound functions
 
 
-
 void lives_tooltips_copy(LiVESWidget *dest, LiVESWidget *source) {
 #if GTK_CHECK_VERSION(2,12,0)
   gchar *text=gtk_widget_get_tooltip_text(source);
@@ -384,15 +581,32 @@ void lives_combo_populate(LiVESCombo *combo, LiVESList *list) {
 
 
 LiVESWidget *lives_standard_label_new(const char *text) {
-  LiVESWidget *label;
+  LiVESWidget *label=NULL;
 #ifdef GUI_GTK
 
   label=gtk_label_new(text);
 
-  if (palette->style&STYLE_1) {
+  if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
     gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
   }
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+  gtk_label_set_justify (GTK_LABEL (label), widget_opts.justify);
+#endif
+
+  return label;
+}
+
+
+LiVESWidget *lives_standard_label_new_with_mnemonic(const char *text, LiVESWidget *mnemonic_widget) {
+  LiVESWidget *label=NULL;
+#ifdef GUI_GTK
+
+  label=gtk_label_new_with_mnemonic(text);
+
+  if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
+  }
+  gtk_label_set_justify (GTK_LABEL (label), widget_opts.justify);
+  if (mnemonic_widget!=NULL) gtk_label_set_mnemonic_widget (GTK_LABEL(label),mnemonic_widget);
 #endif
 
   return label;
@@ -401,49 +615,59 @@ LiVESWidget *lives_standard_label_new(const char *text) {
 
 LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_mnemonic, LiVESBox *box, 
 					     const char *tooltip) {
-  LiVESWidget *checkbutton;
+  LiVESWidget *checkbutton=NULL;
 
   // pack a themed check button into box
 
 
 #ifdef GUI_GTK
-  LiVESWidget *eventbox;
+  LiVESWidget *eventbox=NULL;
   LiVESWidget *label;
   LiVESWidget *hbox;
 
   checkbutton = gtk_check_button_new ();
   if (tooltip!=NULL) lives_tooltips_set(checkbutton, tooltip);
-  eventbox=gtk_event_box_new();
-  if (tooltip!=NULL) lives_tooltips_copy(eventbox,checkbutton);
-  if (use_mnemonic) {
-    label=gtk_label_new_with_mnemonic (labeltext);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),checkbutton);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  }
-  else label=lives_standard_label_new (labeltext);
 
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    checkbutton);
-  
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+  if (labeltext!=NULL) {
+    eventbox=gtk_event_box_new();
+    if (tooltip!=NULL) lives_tooltips_copy(eventbox,checkbutton);
+
+    if (use_mnemonic) {
+      label=lives_standard_label_new_with_mnemonic (labeltext,checkbutton);
+    }
+    else label=lives_standard_label_new (labeltext);
+
+    gtk_container_add(GTK_CONTAINER(eventbox),label);
   }
-  
+
   if (GTK_IS_HBOX(box)) hbox=GTK_WIDGET(box);
   else {
     hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
   
   gtk_box_set_homogeneous(GTK_BOX(hbox),FALSE);
   
-  gtk_box_pack_start (GTK_BOX (hbox), checkbutton, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-  GTK_WIDGET_SET_FLAGS (checkbutton, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
+
+  if (!widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
+
+  if (eventbox!=NULL) 
+    g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
+		      G_CALLBACK (label_act_toggle),
+		      checkbutton);
+  
+  if (eventbox!=NULL&&mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
+    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+  }
+  
+  gtk_box_pack_start (GTK_BOX (hbox), checkbutton, FALSE, FALSE, W_PACKING_WIDTH);
+
+  if (widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
+
+  lives_widget_set_can_focus_and_default(checkbutton);
 #endif
 
   return checkbutton;
@@ -454,14 +678,14 @@ LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_
 
 LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_mnemonic, LiVESSList *rbgroup, 
 					     LiVESBox *box, const char *tooltip) {
-  LiVESWidget *radiobutton;
+  LiVESWidget *radiobutton=NULL;
 
   // pack a themed check button into box
 
 
 
 #ifdef GUI_GTK
-  LiVESWidget *eventbox;
+  LiVESWidget *eventbox=NULL;
   LiVESWidget *label;
   LiVESWidget *hbox;
 
@@ -469,37 +693,46 @@ LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_
 
   if (tooltip!=NULL) lives_tooltips_set(radiobutton, tooltip);
 
-  GTK_WIDGET_SET_FLAGS (radiobutton, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
+  lives_widget_set_can_focus_and_default(radiobutton);
+
   if (GTK_IS_HBOX(box)) hbox=GTK_WIDGET(box);
   else {
     hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
 
   gtk_box_set_homogeneous(GTK_BOX(hbox),FALSE);
 
-  gtk_box_pack_start (GTK_BOX (hbox), radiobutton, FALSE, FALSE, 10);
-      
-  if (use_mnemonic) {
-    label=gtk_label_new_with_mnemonic (labeltext);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),radiobutton);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  }
-  else label=lives_standard_label_new (labeltext);
+  if (labeltext!=NULL) {
+    if (use_mnemonic) {
+      label=lives_standard_label_new_with_mnemonic (labeltext,radiobutton);
+    }
+    else label=lives_standard_label_new (labeltext);
+    
+    eventbox=gtk_event_box_new();
+    if (tooltip!=NULL) lives_tooltips_copy(eventbox,radiobutton);
+    gtk_container_add(GTK_CONTAINER(eventbox),label);
 
-  eventbox=gtk_event_box_new();
-  if (tooltip!=NULL) lives_tooltips_copy(eventbox,radiobutton);
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    radiobutton);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+    if (widget_opts.swap_label&&eventbox!=NULL)
+      gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
- 
+
+  gtk_box_pack_start (GTK_BOX (hbox), radiobutton, FALSE, FALSE, W_PACKING_WIDTH);
+
+  if (eventbox!=NULL) {
+    g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
+		      G_CALLBACK (label_act_toggle),
+		      radiobutton);
+    
+    if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+      gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
+      gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+    }
+    
+    if (!widget_opts.swap_label)
+      gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
+  }
+
 #endif
 
   return radiobutton;
@@ -511,13 +744,13 @@ LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_
 LiVESWidget *lives_standard_spin_button_new(const char *labeltext, boolean use_mnemonic, double val, double min, 
 					    double max, double step, double page, int dp, LiVESBox *box, 
 					    const char *tooltip) {
-  LiVESWidget *spinbutton;
+  LiVESWidget *spinbutton=NULL;
 
   // pack a themed check button into box
 
 
 #ifdef GUI_GTK
-  LiVESWidget *eventbox;
+  LiVESWidget *eventbox=NULL;
   LiVESWidget *label;
   LiVESWidget *hbox;
   LiVESObject *adj;
@@ -537,35 +770,39 @@ LiVESWidget *lives_standard_spin_button_new(const char *labeltext, boolean use_m
   g_free (txt);
 
   gtk_entry_set_width_chars (GTK_ENTRY (spinbutton),maxlen+dp<4?4:maxlen+dp+1);
-  GTK_WIDGET_SET_FLAGS (spinbutton, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
-  gtk_entry_set_activates_default (GTK_ENTRY ((GtkEntry *)&(GTK_SPIN_BUTTON (spinbutton)->entry)), TRUE);
+  lives_widget_set_can_focus_and_default(spinbutton);
+  gtk_entry_set_activates_default (GTK_ENTRY (spinbutton), TRUE);
   gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (spinbutton),GTK_UPDATE_ALWAYS);
-  if (use_mnemonic) {
-    label=gtk_label_new_with_mnemonic (labeltext);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),spinbutton);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  }
-  else label=lives_standard_label_new (labeltext);
 
-  eventbox=gtk_event_box_new();
-  if (tooltip!=NULL) lives_tooltips_copy(eventbox,spinbutton);
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+  if (labeltext!=NULL) {
+    if (use_mnemonic) {
+      label=lives_standard_label_new_with_mnemonic (labeltext,spinbutton);
+    }
+    else label=lives_standard_label_new (labeltext);
+    
+    eventbox=gtk_event_box_new();
+    if (tooltip!=NULL) lives_tooltips_copy(eventbox,spinbutton);
+    gtk_container_add(GTK_CONTAINER(eventbox),label);
+    
+    if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+      gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
+      gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+    }
   }
 
   if (GTK_IS_HBOX(box)) hbox=GTK_WIDGET(box);
-
   else {
     hbox = gtk_hbox_new (TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
 
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), spinbutton, FALSE, FALSE, 10);
+  if (!widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
+
+  gtk_box_pack_start (GTK_BOX (hbox), spinbutton, FALSE, FALSE, W_PACKING_WIDTH);
+
+  if (widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
 
 #endif
 
@@ -579,13 +816,13 @@ LiVESWidget *lives_standard_spin_button_new(const char *labeltext, boolean use_m
 
 LiVESWidget *lives_standard_combo_new (const char *labeltext, boolean use_mnemonic, LiVESList *list, LiVESBox *box, 
 				       const char *tooltip) {
-  LiVESWidget *combo;
+  LiVESWidget *combo=NULL;
 
   // pack a themed combo box into box
 
 
 #ifdef GUI_GTK
-  LiVESWidget *eventbox;
+  LiVESWidget *eventbox=NULL;
   LiVESWidget *label;
   LiVESWidget *hbox;
   LiVESEntry *entry;
@@ -595,32 +832,33 @@ LiVESWidget *lives_standard_combo_new (const char *labeltext, boolean use_mnemon
 
   entry=(LiVESEntry *)lives_combo_get_entry(LIVES_COMBO(combo));
 
-  if (use_mnemonic) {
-    label = gtk_label_new_with_mnemonic (labeltext);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET(entry));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  }
-  else label = lives_standard_label_new (labeltext);
-
-  eventbox=gtk_event_box_new();
-  if (tooltip!=NULL) lives_tooltips_copy(eventbox,combo);
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+  if (labeltext!=NULL) {
+    if (use_mnemonic) {
+      label = lives_standard_label_new_with_mnemonic (labeltext,LIVES_WIDGET(entry));
+    }
+    else label = lives_standard_label_new (labeltext);
+    
+    eventbox=gtk_event_box_new();
+    if (tooltip!=NULL) lives_tooltips_copy(eventbox,combo);
+    gtk_container_add(GTK_CONTAINER(eventbox),label);
+    
+    if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+      gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
+      gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
+    }
   }
 
   if (GTK_IS_HBOX(box)) hbox=GTK_WIDGET(box);
-
   else {
     hbox = gtk_hbox_new (TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
 
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, TRUE, 10);
+  if (!widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
+  gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, TRUE, W_PACKING_WIDTH);
+  if (widget_opts.swap_label&&eventbox!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, W_PACKING_WIDTH);
 
   gtk_editable_set_editable (GTK_EDITABLE(entry),FALSE);
   gtk_entry_set_activates_default(entry,TRUE);
@@ -637,10 +875,10 @@ LiVESWidget *lives_standard_combo_new (const char *labeltext, boolean use_mnemon
 LiVESWidget *lives_standard_entry_new(const char *labeltext, boolean use_mnemonic, char *txt, int dispwidth, int maxchars, LiVESBox *box, 
 					     const char *tooltip) {
 
-  LiVESWidget *entry;
+  LiVESWidget *entry=NULL;
 
 #ifdef GUI_GTK
-  LiVESWidget *label;
+  LiVESWidget *label=NULL;
 
   LiVESWidget *hbox;
 
@@ -652,7 +890,7 @@ LiVESWidget *lives_standard_entry_new(const char *labeltext, boolean use_mnemoni
 
   else {
     hbox = gtk_hbox_new (TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, W_PACKING_WIDTH);
   }
 
   gtk_box_set_homogeneous(GTK_BOX(hbox),FALSE);
@@ -663,21 +901,22 @@ LiVESWidget *lives_standard_entry_new(const char *labeltext, boolean use_mnemoni
   if (dispwidth!=-1) gtk_entry_set_width_chars (GTK_ENTRY (entry),dispwidth);
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 
-  if (use_mnemonic) {
-    label = gtk_label_new_with_mnemonic (labeltext);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),entry);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  }
-  else label = lives_standard_label_new (labeltext);
+  if (labeltext!=NULL) {
+    if (use_mnemonic) {
+      label = lives_standard_label_new_with_mnemonic (labeltext,entry);
+    }
+    else label = lives_standard_label_new (labeltext);
 
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
+    if (tooltip!=NULL) lives_tooltips_copy(label,entry);
   }
 
-  if (tooltip!=NULL) lives_tooltips_copy(label,entry);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 10);
+  if (!widget_opts.swap_label&&label!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, W_PACKING_WIDTH);
   
-  gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 10);
+  gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, W_PACKING_WIDTH);
+
+  if (widget_opts.swap_label&&label!=NULL)
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, W_PACKING_WIDTH);
 #endif
 
   return entry;
@@ -685,21 +924,91 @@ LiVESWidget *lives_standard_entry_new(const char *labeltext, boolean use_mnemoni
 
 
 
+LiVESWidget *lives_standard_dialog_new(const char *title, boolean add_std_buttons) {
+  LiVESWidget *dialog=NULL;
+
+#ifdef GUI_GTK
+
+  dialog = gtk_dialog_new ();
+  gtk_window_set_title (GTK_WINDOW (dialog), title);
+
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+
+  if (prefs->gui_monitor!=0) {
+    gtk_window_set_screen(GTK_WINDOW(dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
+  }
+
+  gtk_container_set_border_width (GTK_CONTAINER (dialog), W_BORDER_WIDTH);
+  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ALWAYS);
+
+  if (mainw!=NULL&&mainw->is_ready&&(palette->style&STYLE_1)) {
+    gtk_widget_modify_bg(dialog, GTK_STATE_NORMAL, &palette->normal_back);
+    gtk_dialog_set_has_separator(GTK_DIALOG(dialog),FALSE);
+  }
+
+  if (add_std_buttons) {
+    GtkAccelGroup *accel_group=GTK_ACCEL_GROUP(gtk_accel_group_new ());
+    GtkWidget *cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
+    GtkWidget *okbutton = gtk_button_new_from_stock ("gtk-ok");
+
+    gtk_window_add_accel_group (GTK_WINDOW (dialog), accel_group);
+
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+
+    gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+				GDK_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+    lives_widget_set_can_focus_and_default(cancelbutton);
+
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+
+    lives_widget_set_can_focus_and_default(okbutton);
+    gtk_widget_grab_default (okbutton);
+  }
+
+  g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+                      G_CALLBACK (return_true),
+                      NULL);
+
+#endif
+
+  return dialog;
+
+}
 
 
+LiVESWidget *lives_standard_hruler_new(void) {
+  LiVESWidget *hruler=NULL;
+
+#ifdef GUI_GTK
+#if GTK_VERSION_3
+  hruler=gtk_scale_new(GTK_ORIENTATION_HORIZONTAL,NULL);
+  gtk_scale_set_draw_value(GTK_SCALE(hruler),FALSE);
+  gtk_scale_set_has_origin(GTK_SCALE(hruler),FALSE);
+  gtk_scale_set_digits(GTK_SCALE(hruler),8);
+#else
+  hruler=gtk_hruler_new();
+#endif
+#endif
+
+  return hruler;
+}
 
 
 
 // utils
 
+void lives_widget_unparent(LiVESWidget *widget) {
+  lives_container_remove(LIVES_CONTAINER(lives_widget_get_parent(widget)),widget);
+}
+
 boolean label_act_toggle (LiVESWidget *widget, LiVESEventButton *event, LiVESToggleButton *togglebutton) {
-  if (!LIVES_WIDGET_IS_SENSITIVE(togglebutton)) return FALSE;
+  if (!lives_widget_is_sensitive(LIVES_WIDGET(togglebutton))) return FALSE;
   lives_toggle_button_set_active (togglebutton, !lives_toggle_button_get_active(togglebutton));
   return FALSE;
 }
 
 boolean widget_act_toggle (LiVESWidget *widget, LiVESToggleButton *togglebutton) {
-  if (!LIVES_WIDGET_IS_SENSITIVE(togglebutton)) return FALSE;
+  if (!lives_widget_is_sensitive(LIVES_WIDGET(togglebutton))) return FALSE;
   lives_toggle_button_set_active (togglebutton, TRUE);
   return FALSE;
 }
@@ -710,20 +1019,6 @@ LIVES_INLINE void toggle_button_toggle (LiVESToggleButton *tbutton) {
 }
 
 
-void set_fg_colour(gint red, gint green, gint blue) {
-  // TODO *** - replace with cairo functions
-  GdkColor col;
-  col.red=red*255;
-  col.green=green*255;
-  col.blue=blue*255;
-  if (mainw->general_gc==NULL) {
-    if (mainw->multitrack==NULL) mainw->general_gc=gdk_gc_new(GDK_DRAWABLE(mainw->LiVES->window));
-    else mainw->general_gc=gdk_gc_new(GDK_DRAWABLE(mainw->multitrack->window->window));
-  }
-  gdk_gc_set_rgb_fg_color(mainw->general_gc,&col);
-}
-
-
 char *text_view_get_text(LiVESTextView *textview) {
   GtkTextIter siter,eiter;
   GtkTextBuffer *textbuf=gtk_text_view_get_buffer (textview);
@@ -741,13 +1036,13 @@ void text_view_set_text(LiVESTextView *textview, const gchar *text) {
 
 
 int get_box_child_index (LiVESBox *box, LiVESWidget *tchild) {
-  GList *list=box->children;
-  GtkBoxChild *child;
+  GList *list=gtk_container_get_children(GTK_CONTAINER(box));
+  GtkWidget *child;
   int i=0;
 
   while (list!=NULL) {
-    child=(GtkBoxChild *)list->data;
-    if (child->widget==tchild) return i;
+    child=(GtkWidget *)list->data;
+    if (child==tchild) return i;
     list=list->next;
     i++;
   }
@@ -764,7 +1059,7 @@ void adjustment_configure(LiVESAdjustment *adjustment,
 		     double page_size) {
   g_object_freeze_notify (G_OBJECT(adjustment));
 
-#ifdef HAVE_GTK_NICE_VERSION
+#if GTK_CHECK_VERSION(2,14,0)
   gtk_adjustment_configure(adjustment,value,lower,upper,step_increment,page_increment,page_size);
   g_object_thaw_notify (G_OBJECT(adjustment));
   return;
@@ -788,8 +1083,8 @@ void lives_set_cursor_style(lives_cursor_t cstyle, LiVESXWindow *window) {
   mainw->cursor=NULL;
 
   if (window==NULL) {
-    if (mainw->multitrack==NULL&&mainw->is_ready) window=mainw->LiVES->window;
-    else if (mainw->multitrack!=NULL&&mainw->multitrack->is_ready) window=mainw->multitrack->window->window;
+    if (mainw->multitrack==NULL&&mainw->is_ready) window=lives_widget_get_xwindow(mainw->LiVES);
+    else if (mainw->multitrack!=NULL&&mainw->multitrack->is_ready) window=lives_widget_get_xwindow(mainw->multitrack->window);
     else return;
   }
 
@@ -843,8 +1138,8 @@ GdkPixbuf *pixbuf;
     mask = gdk_bitmap_create_from_data (NULL, cursormask_bits,
 					1, 1);
     hidden_cursor = gdk_cursor_new_from_pixmap (source, mask, &fg, &bg, 0, 0);
-    gdk_pixmap_unref (source);
-    gdk_pixmap_unref (mask);
+    g_object_unref (source);
+    g_object_unref (mask);
   }
 #endif 
   if (GDK_IS_WINDOW(window))
@@ -861,10 +1156,57 @@ void unhide_cursor(LiVESXWindow *window) {
 void get_border_size (LiVESWidget *win, int *bx, int *by) {
   GdkRectangle rect;
   gint wx,wy;
-  gdk_window_get_frame_extents (GDK_WINDOW (win->window),&rect);
-  gdk_window_get_origin (GDK_WINDOW (win->window), &wx, &wy);
+  gdk_window_get_frame_extents (lives_widget_get_xwindow (win),&rect);
+  gdk_window_get_origin (lives_widget_get_xwindow (win), &wx, &wy);
   *bx=wx-rect.x;
   *by=wy-rect.y;
 }
 
 
+
+
+/*
+ * Set active string to the combo box
+ */
+void lives_combo_set_active_string(LiVESCombo *combo, const char *active_str) {
+
+#ifdef GUI_GTK
+  gtk_entry_set_text(GTK_ENTRY(lives_bin_get_child(LIVES_BIN(combo))),active_str);
+#endif
+
+}
+
+LiVESWidget *lives_combo_get_entry(LiVESCombo *widget) {
+  return lives_bin_get_child(LIVES_BIN(widget));
+}
+
+
+void lives_widget_set_can_focus_and_default(LiVESWidget *widget) {
+  lives_widget_set_can_focus(widget,TRUE);
+  lives_widget_set_can_default(widget,TRUE);
+}
+
+
+
+void lives_general_button_clicked (LiVESButton *button, LiVESObjectPtr data_to_free) {
+  // destroy the button top-level and free data
+
+#ifdef GUI_GTK
+  gtk_widget_destroy(gtk_widget_get_toplevel(GTK_WIDGET(button)));
+
+  if (data_to_free!=NULL) g_free(data_to_free);
+#endif
+}
+
+
+boolean lives_general_delete_event(LiVESWidget *widget, LiVESEvent *event, LiVESObjectPtr data_to_free) {
+#ifdef GUI_GTK
+  gtk_widget_destroy(widget);
+
+  if (data_to_free!=NULL) g_free(data_to_free);
+#endif
+
+  return TRUE;
+}
+
+
